JSDoc: Class: ShapeEditor

# Class: ShapeEditor

## SlickGridShapes.ShapeEditor

ShapeEditor

This class represents a dropdown editor defined by the SlickGrid project.

Note, this object is heavily based on classes in slick.editors.js and in the documentation that can be found here

Also see ShapeFormatter, a function in charge of formatting a dropdown for the SlickGrid object.

## Constructor

#### new ShapeEditor(args)

##### Parameters:

Name | Type | Description
--- | --- | ---
`args` | Object | Arguments passed by SlickGrid.

Source:
  - shape-editor.js, line 30